# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/entities/v1/entities_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-strmprivacy/api/entities/v1/entities_v1.proto\x12\x1bstrmprivacy.api.entities.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1agoogle/type/datetime.proto\"\xeb\x04\n\x06Stream\x12=\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x03\xe0\x41\x02R\x03ref\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12%\n\x0e\x63onsent_levels\x18\x03 \x03(\x05R\rconsentLevels\x12[\n\x12\x63onsent_level_type\x18\x04 \x01(\x0e\x32-.strmprivacy.api.entities.v1.ConsentLevelTypeR\x10\x63onsentLevelType\x12\x1d\n\x07\x65nabled\x18\x05 \x01(\x08\x42\x03\xe0\x41\x03R\x07\x65nabled\x12@\n\x06limits\x18\x06 \x01(\x0b\x32#.strmprivacy.api.entities.v1.LimitsB\x03\xe0\x41\x03R\x06limits\x12#\n\rlinked_stream\x18\x07 \x01(\tR\x0clinkedStream\x12\x12\n\x04tags\x18\x08 \x03(\tR\x04tags\x12O\n\x0b\x63redentials\x18\t \x03(\x0b\x32(.strmprivacy.api.entities.v1.CredentialsB\x03\xe0\x41\x03R\x0b\x63redentials\x12N\n\rmasked_fields\x18\n \x01(\x0b\x32).strmprivacy.api.entities.v1.MaskedFieldsR\x0cmaskedFields\x12$\n\x0bkafka_topic\x18\x0b \x01(\tB\x03\xe0\x41\x03R\nkafkaTopic\x12\x1b\n\tpolicy_id\x18\x0c \x01(\tR\x08policyId\"\x96\x01\n\x0e\x45xtendedStream\x12;\n\x06stream\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.StreamR\x06stream\x12\x14\n\x05topic\x18\x02 \x01(\tR\x05topic\x12\x12\n\x04uuid\x18\x03 \x01(\tR\x04uuid\x12\x1d\n\nkey_stream\x18\x04 \x01(\x08R\tkeyStream\"\xbd\x01\n\x13\x45xtendedStreamGroup\x12P\n\rsource_stream\x18\x01 \x01(\x0b\x32+.strmprivacy.api.entities.v1.ExtendedStreamR\x0csourceStream\x12T\n\x0f\x64\x65rived_streams\x18\x02 \x03(\x0b\x32+.strmprivacy.api.entities.v1.ExtendedStreamR\x0e\x64\x65rivedStreams\"\xd3\x02\n\x0cMaskedFields\x12\x1b\n\thash_type\x18\x01 \x01(\tR\x08hashType\x12\x12\n\x04seed\x18\x02 \x01(\tR\x04seed\x12\x63\n\x0e\x66ield_patterns\x18\x03 \x03(\x0b\x32<.strmprivacy.api.entities.v1.MaskedFields.FieldPatternsEntryR\rfieldPatterns\x1aw\n\x12\x46ieldPatternsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12K\n\x05value\x18\x02 \x01(\x0b\x32\x35.strmprivacy.api.entities.v1.MaskedFields.PatternListR\x05value:\x02\x38\x01\x1a\x34\n\x0bPatternList\x12%\n\x0e\x66ield_patterns\x18\x01 \x03(\tR\rfieldPatterns\"R\n\x06Limits\x12\"\n\nevent_rate\x18\x01 \x01(\x03\x42\x03\xe0\x41\x03R\teventRate\x12$\n\x0b\x65vent_count\x18\x02 \x01(\x03\x42\x03\xe0\x41\x03R\neventCount\"\x90\x01\n\tKeyStream\x12@\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KeyStreamRefB\x03\xe0\x41\x02R\x03ref\x12\x1b\n\x06status\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x06status\x12$\n\x0bkafka_topic\x18\x03 \x01(\tB\x03\xe0\x41\x03R\nkafkaTopic\"k\n\tStreamRef\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\tprojectId\"n\n\x0cKeyStreamRef\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\tprojectId\"\xa0\x01\n\x0b\x43redentials\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12 \n\tclient_id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x08\x63lientId\x12(\n\rclient_secret\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x0c\x63lientSecret\x12\"\n\nproject_id\x18\x04 \x01(\tB\x03\xe0\x41\x03R\tprojectId\"\xdf\x01\n\x04Sink\x12;\n\x03ref\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.SinkRefB\x03\xe0\x41\x02R\x03ref\x12G\n\tsink_type\x18\x02 \x01(\x0e\x32%.strmprivacy.api.entities.v1.SinkTypeB\x03\xe0\x41\x02R\x08sinkType\x12\x43\n\x06\x62ucket\x18\x04 \x01(\x0b\x32).strmprivacy.api.entities.v1.BucketConfigH\x00R\x06\x62ucket:\x02\x18\x01\x42\x08\n\x06\x63onfig\"J\n\x07SinkRef\x12\"\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tbillingId\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name:\x02\x18\x01\"\x83\x01\n\x0c\x42ucketConfig\x12$\n\x0b\x62ucket_name\x18\x04 \x01(\tB\x03\xe0\x41\x02R\nbucketName\x12%\n\x0b\x63redentials\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x0b\x63redentials\x12&\n\x0f\x61ssume_role_arn\x18\x06 \x01(\tR\rassumeRoleArn\"\xb1\x04\n\rDataConnector\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefR\x03ref\x12O\n\ts3_bucket\x18\x02 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.AwsS3BucketLocationH\x00R\x08s3Bucket\x12~\n\x1bgoogle_cloud_storage_bucket\x18\x03 \x01(\x0b\x32=.strmprivacy.api.entities.v1.GoogleCloudStorageBucketLocationH\x00R\x18googleCloudStorageBucket\x12\x81\x01\n\x1c\x61zure_blob_storage_container\x18\x04 \x01(\x0b\x32>.strmprivacy.api.entities.v1.AzureBlobStorageContainerLocationH\x00R\x19\x61zureBlobStorageContainer\x12\x12\n\x04uuid\x18\x05 \x01(\tR\x04uuid\x12j\n\x12\x64\x65pendent_entities\x18\x06 \x01(\x0b\x32;.strmprivacy.api.entities.v1.DataConnectorDependentEntitiesR\x11\x64\x65pendentEntitiesB\n\n\x08location\"h\n\x10\x44\x61taConnectorRef\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1d\n\nproject_id\x18\x03 \x01(\tR\tprojectId\"\xb3\x02\n\x1e\x44\x61taConnectorDependentEntities\x12S\n\x0f\x62\x61tch_exporters\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterR\x0e\x62\x61tchExporters\x12\x44\n\nbatch_jobs\x18\x02 \x03(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobR\tbatchJobs\x12v\n\x1cmicro_aggregation_batch_jobs\x18\x03 \x03(\x0b\x32\x35.strmprivacy.api.entities.v1.MicroAggregationBatchJobR\x19microAggregationBatchJobs\"\x8f\x01\n\x13\x41wsS3BucketLocation\x12$\n\x0b\x62ucket_name\x18\x01 \x01(\tB\x03\xe0\x41\x02R\nbucketName\x12%\n\x0b\x63redentials\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0b\x63redentials\x12+\n\x0f\x61ssume_role_arn\x18\x03 \x01(\tB\x03\xe0\x41\x01R\rassumeRoleArn\"o\n GoogleCloudStorageBucketLocation\x12$\n\x0b\x62ucket_name\x18\x01 \x01(\tB\x03\xe0\x41\x02R\nbucketName\x12%\n\x0b\x63redentials\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0b\x63redentials\"\xfd\x01\n!AzureBlobStorageContainerLocation\x12\x33\n\x13storage_account_uri\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x11storageAccountUri\x12*\n\x0e\x63ontainer_name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\rcontainerName\x12w\n\x18\x63lient_secret_credential\x18\x03 \x01(\x0b\x32\x38.strmprivacy.api.entities.v1.AzureClientSecretCredentialB\x03\xe0\x41\x02R\x16\x63lientSecretCredential\"\x8b\x01\n\x1b\x41zureClientSecretCredential\x12 \n\ttenant_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x08tenantId\x12 \n\tclient_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08\x63lientId\x12(\n\rclient_secret\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x0c\x63lientSecret\"S\n\x08\x44\x61taType\x12:\n\x03\x63sv\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.CsvConfigH\x00R\x03\x63svB\x0b\n\tdata_type\"%\n\tCsvConfig\x12\x18\n\x07\x63harset\x18\x01 \x01(\tR\x07\x63harset\"\xab\x04\n\rBatchExporter\x12\x44\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.BatchExporterRefB\x03\xe0\x41\x02R\x03ref\x12L\n\nstream_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x03\xe0\x41\x02H\x00R\tstreamRef\x12V\n\x0ekey_stream_ref\x18\x03 \x01(\x0b\x32).strmprivacy.api.entities.v1.KeyStreamRefB\x03\xe0\x41\x02H\x00R\x0ckeyStreamRef\x12:\n\x08interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x03\xe0\x41\x02R\x08interval\x12 \n\tsink_name\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x08sinkName\x12\x1f\n\x0bpath_prefix\x18\x06 \x01(\tR\npathPrefix\x12\x36\n\x17include_existing_events\x18\x07 \x01(\x08R\x15includeExistingEvents\x12[\n\x12\x64\x61ta_connector_ref\x18\x08 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefR\x10\x64\x61taConnectorRefB\x1a\n\x18stream_or_key_stream_ref\"\x89\x01\n\x15\x45xtendedBatchExporter\x12\x12\n\x04uuid\x18\x01 \x01(\tR\x04uuid\x12\x14\n\x05topic\x18\x02 \x01(\tR\x05topic\x12\x46\n\x08\x65xporter\x18\x03 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterR\x08\x65xporter\"r\n\x10\x42\x61tchExporterRef\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\tprojectId\"\xfa\x01\n\x0cKafkaCluster\x12\x43\n\x03ref\x18\x01 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x03\xe0\x41\x02R\x03ref\x12\x30\n\x11\x62ootstrap_servers\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x10\x62ootstrapServers\x12V\n\x0e\x61uth_mechanism\x18\x03 \x01(\x0e\x32*.strmprivacy.api.entities.v1.AuthMechanismB\x03\xe0\x41\x02R\rauthMechanism\x12\x1b\n\ttoken_uri\x18\x04 \x01(\tR\x08tokenUri\"q\n\x0fKafkaClusterRef\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\xae\x02\n\rKafkaExporter\x12\x44\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.KafkaExporterRefB\x03\xe0\x41\x02R\x03ref\x12J\n\nstream_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x03\xe0\x41\x02R\tstreamRef\x12M\n\x06target\x18\x03 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.KafkaExporterTargetB\x03\xe0\x41\x02R\x06target\x12<\n\x05users\x18\x04 \x03(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUserR\x05users\"r\n\x10KafkaExporterRef\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\xc6\x01\n\x13KafkaExporterTarget\x12R\n\x0b\x63luster_ref\x18\x01 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x03\xe0\x41\x02R\nclusterRef\x12\x19\n\x05topic\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x05topic\x12\x1b\n\tclient_id\x18\x03 \x01(\tR\x08\x63lientId\x12#\n\rclient_secret\x18\x04 \x01(\tR\x0c\x63lientSecret\"\xbd\x02\n\tKafkaUser\x12@\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaUserRefB\x03\xe0\x41\x02R\x03ref\x12\x33\n\x13kafka_exporter_name\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x11kafkaExporterName\x12\x19\n\x05topic\x18\x04 \x01(\tB\x03\xe0\x41\x03R\x05topic\x12 \n\tclient_id\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x08\x63lientId\x12(\n\rclient_secret\x18\x06 \x01(\tB\x03\xe0\x41\x03R\x0c\x63lientSecret\x12R\n\x0b\x63luster_ref\x18\x07 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefB\x03\xe0\x41\x03R\nclusterRef\"n\n\x0cKafkaUserRef\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x04name\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\tprojectId\"6\n\rConsentLevels\x12%\n\x0e\x63onsent_levels\x18\x01 \x03(\x05R\rconsentLevels\"z\n\x13\x43onsentLevelMapping\x12J\n\x03ref\x18\x01 \x01(\x0b\x32\x33.strmprivacy.api.entities.v1.ConsentLevelMappingRefB\x03\xe0\x41\x02R\x03ref\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\"z\n\x16\x43onsentLevelMappingRef\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x19\n\x05level\x18\x02 \x01(\x05\x42\x03\xe0\x41\x02R\x05level\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\tprojectId\"\xc1\x02\n\x06Policy\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12#\n\rlegal_grounds\x18\x04 \x01(\tR\x0clegalGrounds\x12*\n\x0eretention_days\x18\x05 \x01(\x05\x42\x03\xe0\x41\x02R\rretentionDays\x12?\n\x05state\x18\x06 \x01(\x0e\x32).strmprivacy.api.entities.v1.Policy.StateR\x05state\"U\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bSTATE_DRAFT\x10\x01\x12\x10\n\x0cSTATE_ACTIVE\x10\x02\x12\x12\n\x0eSTATE_ARCHIVED\x10\x03\"\xb6\x01\n\x12WindowedEventCount\x12>\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tstartTime\x12:\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\x07\x65ndTime\x12$\n\x0b\x65vent_count\x18\x03 \x01(\x03\x42\x03\xe0\x41\x03R\neventCount\"\xaf\x01\n\tSchemaRef\x12\x1b\n\x06handle\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x06handle\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\x12M\n\x0bschema_type\x18\x04 \x01(\x0e\x32\'.strmprivacy.api.entities.v1.SchemaTypeB\x03\xe0\x41\x03R\nschemaType\"\xd0\x05\n\x06Schema\x12=\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02R\x03ref\x12\x44\n\x05state\x18\x02 \x01(\x0e\x32).strmprivacy.api.entities.v1.Schema.StateB\x03\xe0\x41\x03R\x05state\x12\x1b\n\tis_public\x18\x03 \x01(\x08R\x08isPublic\x12\x1e\n\ndefinition\x18\x04 \x01(\tR\ndefinition\x12%\n\x0b\x66ingerprint\x18\x05 \x01(\tB\x03\xe0\x41\x03R\x0b\x66ingerprint\x12G\n\x08metadata\x18\x06 \x01(\x0b\x32+.strmprivacy.api.entities.v1.SchemaMetadataR\x08metadata\x12_\n\rsimple_schema\x18\x07 \x01(\x0b\x32:.strmprivacy.api.entities.v1.Schema.SimpleSchemaDefinitionR\x0csimpleSchema\x12\x0e\n\x02id\x18\x08 \x01(\tR\x02id\x1a\xbe\x01\n\x16SimpleSchemaDefinition\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12\x10\n\x03\x64oc\x18\x03 \x01(\tR\x03\x64oc\x12\x43\n\x05nodes\x18\x04 \x03(\x0b\x32-.strmprivacy.api.entities.v1.SimpleSchemaNodeR\x05nodes\x12\x1b\n\tavro_name\x18\x05 \x01(\tR\x08\x61vroName\"b\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x41RCHIVED\x10\x03\x12\r\n\tIN_REVIEW\x10\x04\x12\x0e\n\nINCOMPLETE\x10\x05\"\x99\x02\n\x10SimpleSchemaNode\x12\x45\n\x04type\x18\x01 \x01(\x0e\x32\x31.strmprivacy.api.entities.v1.SimpleSchemaNodeTypeR\x04type\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1b\n\tavro_name\x18\x07 \x01(\tR\x08\x61vroName\x12\x1a\n\x08repeated\x18\x03 \x01(\x08R\x08repeated\x12\x1a\n\x08required\x18\x04 \x01(\x08R\x08required\x12\x43\n\x05nodes\x18\x05 \x03(\x0b\x32-.strmprivacy.api.entities.v1.SimpleSchemaNodeR\x05nodes\x12\x10\n\x03\x64oc\x18\x06 \x01(\tR\x03\x64oc\"\xb9\x02\n\x0eSchemaMetadata\x12\x19\n\x05title\x18\x01 \x01(\tB\x03\xe0\x41\x01R\x05title\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x03\xe0\x41\x01R\x0b\x64\x65scription\x12@\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x1e\n\x08icon_uri\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x07iconUri\x12?\n\x06labels\x18\x05 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01R\x06labels\x12\x1d\n\x07\x64omains\x18\x06 \x03(\tB\x03\xe0\x41\x01R\x07\x64omains\x12#\n\nindustries\x18\x07 \x03(\tB\x03\xe0\x41\x01R\nindustries\"g\n\x10\x45ventContractRef\x12\x1b\n\x06handle\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x06handle\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\"\x82\x06\n\rEventContract\x12\x44\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02R\x03ref\x12K\n\x05state\x18\x02 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.EventContract.StateB\x03\xe0\x41\x03R\x05state\x12J\n\nschema_ref\x18\x03 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02R\tschemaRef\x12\x1b\n\tis_public\x18\x04 \x01(\x08R\x08isPublic\x12 \n\tkey_field\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x08keyField\x12X\n\npii_fields\x18\x06 \x03(\x0b\x32\x39.strmprivacy.api.entities.v1.EventContract.PiiFieldsEntryR\tpiiFields\x12I\n\x0bvalidations\x18\x07 \x03(\x0b\x32\'.strmprivacy.api.entities.v1.ValidationR\x0bvalidations\x12N\n\x08metadata\x18\x08 \x01(\x0b\x32\x32.strmprivacy.api.entities.v1.EventContractMetadataR\x08metadata\x12\x0e\n\x02id\x18\t \x01(\tR\x02id\x12,\n\x12\x64\x61ta_subject_field\x18\n \x01(\tR\x10\x64\x61taSubjectField\x1a<\n\x0ePiiFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\"b\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x41RCHIVED\x10\x03\x12\r\n\tIN_REVIEW\x10\x04\x12\x0e\n\nINCOMPLETE\x10\x05\"\xc0\x02\n\x15\x45ventContractMetadata\x12\x19\n\x05title\x18\x01 \x01(\tB\x03\xe0\x41\x01R\x05title\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x03\xe0\x41\x01R\x0b\x64\x65scription\x12@\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12\x1e\n\x08icon_uri\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x07iconUri\x12?\n\x06labels\x18\x05 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01R\x06labels\x12\x1d\n\x07\x64omains\x18\x06 \x03(\tB\x03\xe0\x41\x01R\x07\x64omains\x12#\n\nindustries\x18\x07 \x03(\tB\x03\xe0\x41\x01R\nindustries\"9\n\x05Label\x12\x15\n\x03key\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x03key\x12\x19\n\x05value\x18\x02 \x01(\tB\x03\xe0\x41\x01R\x05value\"[\n\nValidation\x12\x19\n\x05\x66ield\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05\x66ield\x12\x17\n\x04type\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04type\x12\x19\n\x05value\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x05value\"\xfe\x02\n\nStreamTree\x12@\n\x06stream\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.StreamB\x03\xe0\x41\x02R\x06stream\x12\x45\n\nkey_stream\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KeyStreamR\tkeyStream\x12=\n\x07\x64\x65rived\x18\x03 \x03(\x0b\x32#.strmprivacy.api.entities.v1.StreamR\x07\x64\x65rived\x12S\n\x0f\x62\x61tch_exporters\x18\x04 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterR\x0e\x62\x61tchExporters\x12S\n\x0fkafka_exporters\x18\x05 \x03(\x0b\x32*.strmprivacy.api.entities.v1.KafkaExporterR\x0ekafkaExporters\"\x9f\x01\n\x08SinkTree\x12:\n\x04sink\x18\x01 \x01(\x0b\x32!.strmprivacy.api.entities.v1.SinkB\x03\xe0\x41\x02R\x04sink\x12S\n\x0f\x62\x61tch_exporters\x18\x02 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterR\x0e\x62\x61tchExporters:\x02\x18\x01\"\xa2\x06\n\x08\x42\x61tchJob\x12?\n\x03ref\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefB\x03\xe0\x41\x02R\x03ref\x12G\n\x06states\x18\x02 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchJobStateB\x03\xe0\x41\x03R\x06states\x12W\n\x0bsource_data\x18\x03 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x03\xe0\x41\x02R\nsourceData\x12I\n\x07\x63onsent\x18\x04 \x01(\x0b\x32*.strmprivacy.api.entities.v1.ConsentConfigB\x03\xe0\x41\x02R\x07\x63onsent\x12R\n\nencryption\x18\x05 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EncryptionConfigB\x03\xe0\x41\x02R\nencryption\x12`\n\x12\x65vent_contract_ref\x18\x06 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02R\x10\x65ventContractRef\x12V\n\x0e\x65ncrypted_data\x18\x07 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EncryptedDataB\x03\xe0\x41\x02R\rencryptedData\x12\x66\n\x14\x65ncryption_keys_data\x18\x08 \x01(\x0b\x32/.strmprivacy.api.entities.v1.EncryptionKeysDataB\x03\xe0\x41\x02R\x12\x65ncryptionKeysData\x12P\n\x0c\x64\x65rived_data\x18\t \x03(\x0b\x32(.strmprivacy.api.entities.v1.DerivedDataB\x03\xe0\x41\x01R\x0b\x64\x65rivedData\x12 \n\tpolicy_id\x18\n \x01(\tB\x03\xe0\x41\x02R\x08policyId\"\xeb\x01\n\x0f\x42\x61tchJobWrapper\x12Y\n\x14\x65ncryption_batch_job\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobH\x00R\x12\x65ncryptionBatchJob\x12v\n\x1bmicro_aggregation_batch_job\x18\x02 \x01(\x0b\x32\x35.strmprivacy.api.entities.v1.MicroAggregationBatchJobH\x00R\x18microAggregationBatchJobB\x05\n\x03job\"\x9a\x01\n\x10\x45xtendedBatchJob\x12\x46\n\tbatch_job\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobB\x02\x18\x01R\x08\x62\x61tchJob\x12>\n\x03job\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.BatchJobWrapperR\x03job\"i\n\x0b\x42\x61tchJobRef\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x13\n\x02id\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x02id\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x03R\tprojectId\"\xb9\x01\n\rBatchJobState\x12>\n\nstate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tstateTime\x12I\n\x05state\x18\x02 \x01(\x0e\x32..strmprivacy.api.entities.v1.BatchJobStateTypeB\x03\xe0\x41\x02R\x05state\x12\x1d\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x07message\"\x89\x02\n\x14\x44\x61taConnectorAndType\x12`\n\x12\x64\x61ta_connector_ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefB\x03\xe0\x41\x02R\x10\x64\x61taConnectorRef\x12$\n\x0bpath_prefix\x18\x02 \x01(\tB\x03\xe0\x41\x01R\npathPrefix\x12 \n\tfile_name\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x08\x66ileName\x12G\n\tdata_type\x18\x04 \x01(\x0b\x32%.strmprivacy.api.entities.v1.DataTypeB\x03\xe0\x41\x02R\x08\x64\x61taType\"\xbb\x01\n\rConsentConfig\x12\x39\n\x16\x64\x65\x66\x61ult_consent_levels\x18\x01 \x03(\x05\x42\x03\xe0\x41\x01R\x14\x64\x65\x66\x61ultConsentLevels\x12o\n\x17\x63onsent_level_extractor\x18\x02 \x01(\x0b\x32\x32.strmprivacy.api.entities.v1.ConsentLevelExtractorB\x03\xe0\x41\x01R\x15\x63onsentLevelExtractor\"\x89\x02\n\x15\x43onsentLevelExtractor\x12\x14\n\x05\x66ield\x18\x01 \x01(\tR\x05\x66ield\x12l\n\x0e\x66ield_patterns\x18\x02 \x03(\x0b\x32\x45.strmprivacy.api.entities.v1.ConsentLevelExtractor.FieldPatternsEntryR\rfieldPatterns\x1al\n\x12\x46ieldPatternsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12@\n\x05value\x18\x02 \x01(\x0b\x32*.strmprivacy.api.entities.v1.ConsentLevelsR\x05value:\x02\x38\x01\"\xa2\x01\n\x10\x45ncryptionConfig\x12\\\n\x10timestamp_config\x18\x01 \x01(\x0b\x32,.strmprivacy.api.entities.v1.TimestampConfigB\x03\xe0\x41\x02R\x0ftimestampConfig\x12\x30\n\x12\x62\x61tch_job_group_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x0f\x62\x61tchJobGroupId\"\x91\x01\n\x0fTimestampConfig\x12\x19\n\x05\x66ield\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05\x66ield\x12\x1b\n\x06\x66ormat\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x06\x66ormat\x12\x46\n\x11\x64\x65\x66\x61ult_time_zone\x18\x03 \x01(\x0b\x32\x15.google.type.TimeZoneB\x03\xe0\x41\x01R\x0f\x64\x65\x66\x61ultTimeZone\"_\n\rEncryptedData\x12N\n\x06target\x18\x01 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x03\xe0\x41\x02R\x06target\"d\n\x12\x45ncryptionKeysData\x12N\n\x06target\x18\x01 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x03\xe0\x41\x02R\x06target\"\xb1\x02\n\x0b\x44\x65rivedData\x12N\n\x06target\x18\x01 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x03\xe0\x41\x02R\x06target\x12%\n\x0e\x63onsent_levels\x18\x02 \x03(\x05R\rconsentLevels\x12[\n\x12\x63onsent_level_type\x18\x03 \x01(\x0e\x32-.strmprivacy.api.entities.v1.ConsentLevelTypeR\x10\x63onsentLevelType\x12N\n\rmasked_fields\x18\x04 \x01(\x0b\x32).strmprivacy.api.entities.v1.MaskedFieldsR\x0cmaskedFields\"\x9e\x04\n\x18MicroAggregationBatchJob\x12?\n\x03ref\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefB\x03\xe0\x41\x02R\x03ref\x12G\n\x06states\x18\x02 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchJobStateB\x03\xe0\x41\x02R\x06states\x12W\n\x0bsource_data\x18\x03 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x03\xe0\x41\x02R\nsourceData\x12W\n\x0btarget_data\x18\x04 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataConnectorAndTypeB\x03\xe0\x41\x02R\ntargetData\x12]\n\x11\x64\x61ta_contract_ref\x18\x05 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefB\x03\xe0\x41\x02R\x0f\x64\x61taContractRef\x12g\n\x12\x61ggregation_config\x18\x06 \x01(\x0b\x32\x33.strmprivacy.api.entities.v1.MicroAggregationConfigB\x03\xe0\x41\x02R\x11\x61ggregationConfig\"|\n\x16MicroAggregationConfig\x12\x33\n\x13minimum_k_anonymity\x18\x01 \x01(\x05\x42\x03\xe0\x41\x02R\x11minimumKAnonymity\x12-\n\x12\x61ggregation_fields\x18\x02 \x03(\tR\x11\x61ggregationFields\"f\n\x0f\x44\x61taContractRef\x12\x1b\n\x06handle\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x06handle\x12\x17\n\x04name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x04name\x12\x1d\n\x07version\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x07version\"\xe9\x06\n\x0c\x44\x61taContract\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\x12\x43\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefB\x03\xe0\x41\x02R\x03ref\x12J\n\x05state\x18\x03 \x01(\x0e\x32/.strmprivacy.api.entities.v1.DataContract.StateB\x03\xe0\x41\x03R\x05state\x12\x1b\n\tis_public\x18\x04 \x01(\x08R\x08isPublic\x12 \n\tkey_field\x18\x05 \x01(\tB\x03\xe0\x41\x02R\x08keyField\x12[\n\npii_fields\x18\x06 \x03(\x0b\x32\x38.strmprivacy.api.entities.v1.DataContract.PiiFieldsEntryB\x02\x18\x01R\tpiiFields\x12I\n\x0bvalidations\x18\x07 \x03(\x0b\x32\'.strmprivacy.api.entities.v1.ValidationR\x0bvalidations\x12M\n\x08metadata\x18\x08 \x01(\x0b\x32\x31.strmprivacy.api.entities.v1.DataContractMetadataR\x08metadata\x12;\n\x06schema\x18\t \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaR\x06schema\x12,\n\x12\x64\x61ta_subject_field\x18\n \x01(\tR\x10\x64\x61taSubjectField\x12\x1d\n\nproject_id\x18\x0b \x01(\tR\tprojectId\x12Q\n\x0e\x66ield_metadata\x18\x0c \x03(\x0b\x32*.strmprivacy.api.entities.v1.FieldMetadataR\rfieldMetadata\x1a<\n\x0ePiiFieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\"b\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\t\n\x05\x44RAFT\x10\x01\x12\r\n\tIN_REVIEW\x10\x02\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\x0c\n\x08\x41RCHIVED\x10\x04\x12\x0e\n\nINCOMPLETE\x10\x05\"\x9a\x06\n\rFieldMetadata\x12\x1d\n\nfield_name\x18\x01 \x01(\tR\tfieldName\x12o\n\x14personal_data_config\x18\x02 \x01(\x0b\x32=.strmprivacy.api.entities.v1.FieldMetadata.PersonalDataConfigR\x12personalDataConfig\x12\x64\n\x15statistical_data_type\x18\x03 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.StatisticalDataTypeR\x13statisticalDataType\x12%\n\x0eordinal_values\x18\x04 \x03(\tR\rordinalValues\x12o\n\x14null_handling_config\x18\x05 \x01(\x0b\x32=.strmprivacy.api.entities.v1.FieldMetadata.NullHandlingConfigR\x12nullHandlingConfig\x1az\n\x12PersonalDataConfig\x12\x1a\n\x06is_pii\x18\x01 \x01(\x08\x42\x03\xe0\x41\x02R\x05isPii\x12#\n\x0bis_quasi_id\x18\x02 \x01(\x08\x42\x03\xe0\x41\x02R\tisQuasiId\x12#\n\rpurpose_level\x18\x03 \x01(\x05R\x0cpurposeLevel\x1a\xfe\x01\n\x12NullHandlingConfig\x12g\n\x04type\x18\x01 \x01(\x0e\x32N.strmprivacy.api.entities.v1.FieldMetadata.NullHandlingConfig.NullHandlingTypeB\x03\xe0\x41\x02R\x04type\x12#\n\rdefault_value\x18\x02 \x01(\tR\x0c\x64\x65\x66\x61ultValue\"Z\n\x10NullHandlingType\x12\"\n\x1eNULL_HANDLING_TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x44ROP_RECORD\x10\x01\x12\x11\n\rDEFAULT_VALUE\x10\x02\"\x9f\x02\n\x14\x44\x61taContractMetadata\x12\x19\n\x05title\x18\x01 \x01(\tB\x03\xe0\x41\x01R\x05title\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x03\xe0\x41\x01R\x0b\x64\x65scription\x12@\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\ncreateTime\x12?\n\x06labels\x18\x05 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01R\x06labels\x12\x1d\n\x07\x64omains\x18\x06 \x03(\tB\x03\xe0\x41\x01R\x07\x64omains\x12#\n\nindustries\x18\x07 \x03(\tB\x03\xe0\x41\x01R\nindustries\"\x81\x02\n\x07Project\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\'\n\x0forganization_id\x18\x04 \x01(\tR\x0eorganizationId\x12@\n\x05state\x18\x05 \x01(\x0e\x32*.strmprivacy.api.entities.v1.Project.StateR\x05state\"E\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bOPERATIONAL\x10\x01\x12\x14\n\x10PENDING_DELETION\x10\x02\"\x9e\x01\n\x04User\x12\x14\n\x05\x65mail\x18\x01 \x01(\tR\x05\x65mail\x12\x1d\n\nfirst_name\x18\x02 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x03 \x01(\tR\x08lastName\x12\x44\n\nuser_roles\x18\x04 \x03(\x0e\x32%.strmprivacy.api.entities.v1.UserRoleR\tuserRoles*]\n\x08UserRole\x12\x19\n\x15USER_ROLE_UNSPECIFIED\x10\x00\x12\t\n\x05\x41\x44MIN\x10\x01\x12\x11\n\rPROJECT_ADMIN\x10\x02\x12\x0c\n\x08\x41PPROVER\x10\x03\x12\n\n\x06MEMBER\x10\x04*\x8d\x01\n\x11\x42\x61tchJobStateType\x12$\n BATCH_JOB_STATE_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07STARTED\x10\x02\x12\x12\n\x0e\x45RROR_STARTING\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\x0c\n\x08\x46INISHED\x10\x05\x12\t\n\x05\x45RROR\x10\x06*T\n\x10\x43onsentLevelType\x12\"\n\x1e\x43ONSENT_LEVEL_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nCUMULATIVE\x10\x01\x12\x0c\n\x08GRANULAR\x10\x02*=\n\x08SinkType\x12\x19\n\x15SINK_TYPE_UNSPECIFIED\x10\x00\x12\x06\n\x02S3\x10\x01\x12\n\n\x06GCLOUD\x10\x02\x1a\x02\x18\x01*M\n\rAuthMechanism\x12\x1e\n\x1a\x41UTH_MECHANISM_UNSPECIFIED\x10\x00\x12\x0e\n\nSASL_PLAIN\x10\x01\x12\x0c\n\x08SASL_SSL\x10\x02*C\n\nSchemaType\x12\x1b\n\x17SCHEMA_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x41VRO\x10\x01\x12\x0e\n\nJSONSCHEMA\x10\x02*\x84\x01\n\x14SimpleSchemaNodeType\x12\'\n#SIMPLE_SCHEMA_NODE_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06STRING\x10\x01\x12\x0b\n\x07\x42OOLEAN\x10\x02\x12\t\n\x05\x46LOAT\x10\x03\x12\x0b\n\x07INTEGER\x10\x04\x12\x08\n\x04LONG\x10\x05\x12\x08\n\x04NODE\x10\n*_\n\x13\x46ilterPublicPrivate\x12%\n!FILTER_PUBLIC_PRIVATE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bONLY_PUBLIC\x10\x01\x12\x10\n\x0cONLY_PRIVATE\x10\x02*e\n\x13StatisticalDataType\x12%\n!STATISTICAL_DATA_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07NOMINAL\x10\x01\x12\x0b\n\x07ORDINAL\x10\x02\x12\r\n\tNUMERICAL\x10\x03*\x92\x01\n\x10SubscriptionPlan\x12!\n\x1dSUBSCRIPTION_PLAN_UNSPECIFIED\x10\x00\x12\x08\n\x04\x46REE\x10\x01\x12\x0c\n\x08\x42USINESS\x10\x02\x12\x0f\n\x0bSELF_HOSTED\x10\x03\x12\x18\n\x14\x41WS_MARKETPLACE_PAYG\x10\x04\x12\x18\n\x14\x41WS_MARKETPLACE_BYOL\x10\x05\x42i\n\x1eio.strmprivacy.api.entities.v1P\x01ZEgithub.com/strmprivacy/api-definitions-go/v2/api/entities/v1;entitiesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.entities.v1.entities_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036io.strmprivacy.api.entities.v1P\001ZEgithub.com/strmprivacy/api-definitions-go/v2/api/entities/v1;entities'
  _SINKTYPE._options = None
  _SINKTYPE._serialized_options = b'\030\001'
  _STREAM.fields_by_name['ref']._options = None
  _STREAM.fields_by_name['ref']._serialized_options = b'\340A\002'
  _STREAM.fields_by_name['enabled']._options = None
  _STREAM.fields_by_name['enabled']._serialized_options = b'\340A\003'
  _STREAM.fields_by_name['limits']._options = None
  _STREAM.fields_by_name['limits']._serialized_options = b'\340A\003'
  _STREAM.fields_by_name['credentials']._options = None
  _STREAM.fields_by_name['credentials']._serialized_options = b'\340A\003'
  _STREAM.fields_by_name['kafka_topic']._options = None
  _STREAM.fields_by_name['kafka_topic']._serialized_options = b'\340A\003'
  _MASKEDFIELDS_FIELDPATTERNSENTRY._options = None
  _MASKEDFIELDS_FIELDPATTERNSENTRY._serialized_options = b'8\001'
  _LIMITS.fields_by_name['event_rate']._options = None
  _LIMITS.fields_by_name['event_rate']._serialized_options = b'\340A\003'
  _LIMITS.fields_by_name['event_count']._options = None
  _LIMITS.fields_by_name['event_count']._serialized_options = b'\340A\003'
  _KEYSTREAM.fields_by_name['ref']._options = None
  _KEYSTREAM.fields_by_name['ref']._serialized_options = b'\340A\002'
  _KEYSTREAM.fields_by_name['status']._options = None
  _KEYSTREAM.fields_by_name['status']._serialized_options = b'\340A\003'
  _KEYSTREAM.fields_by_name['kafka_topic']._options = None
  _KEYSTREAM.fields_by_name['kafka_topic']._serialized_options = b'\340A\003'
  _STREAMREF.fields_by_name['billing_id']._options = None
  _STREAMREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _STREAMREF.fields_by_name['name']._options = None
  _STREAMREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _STREAMREF.fields_by_name['project_id']._options = None
  _STREAMREF.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _KEYSTREAMREF.fields_by_name['billing_id']._options = None
  _KEYSTREAMREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _KEYSTREAMREF.fields_by_name['name']._options = None
  _KEYSTREAMREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _KEYSTREAMREF.fields_by_name['project_id']._options = None
  _KEYSTREAMREF.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _CREDENTIALS.fields_by_name['billing_id']._options = None
  _CREDENTIALS.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CREDENTIALS.fields_by_name['client_id']._options = None
  _CREDENTIALS.fields_by_name['client_id']._serialized_options = b'\340A\003'
  _CREDENTIALS.fields_by_name['client_secret']._options = None
  _CREDENTIALS.fields_by_name['client_secret']._serialized_options = b'\340A\003'
  _CREDENTIALS.fields_by_name['project_id']._options = None
  _CREDENTIALS.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _SINK.fields_by_name['ref']._options = None
  _SINK.fields_by_name['ref']._serialized_options = b'\340A\002'
  _SINK.fields_by_name['sink_type']._options = None
  _SINK.fields_by_name['sink_type']._serialized_options = b'\340A\002'
  _SINK._options = None
  _SINK._serialized_options = b'\030\001'
  _SINKREF.fields_by_name['billing_id']._options = None
  _SINKREF.fields_by_name['billing_id']._serialized_options = b'\340A\002'
  _SINKREF.fields_by_name['name']._options = None
  _SINKREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _SINKREF._options = None
  _SINKREF._serialized_options = b'\030\001'
  _BUCKETCONFIG.fields_by_name['bucket_name']._options = None
  _BUCKETCONFIG.fields_by_name['bucket_name']._serialized_options = b'\340A\002'
  _BUCKETCONFIG.fields_by_name['credentials']._options = None
  _BUCKETCONFIG.fields_by_name['credentials']._serialized_options = b'\340A\002'
  _DATACONNECTORREF.fields_by_name['billing_id']._options = None
  _DATACONNECTORREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _AWSS3BUCKETLOCATION.fields_by_name['bucket_name']._options = None
  _AWSS3BUCKETLOCATION.fields_by_name['bucket_name']._serialized_options = b'\340A\002'
  _AWSS3BUCKETLOCATION.fields_by_name['credentials']._options = None
  _AWSS3BUCKETLOCATION.fields_by_name['credentials']._serialized_options = b'\340A\002'
  _AWSS3BUCKETLOCATION.fields_by_name['assume_role_arn']._options = None
  _AWSS3BUCKETLOCATION.fields_by_name['assume_role_arn']._serialized_options = b'\340A\001'
  _GOOGLECLOUDSTORAGEBUCKETLOCATION.fields_by_name['bucket_name']._options = None
  _GOOGLECLOUDSTORAGEBUCKETLOCATION.fields_by_name['bucket_name']._serialized_options = b'\340A\002'
  _GOOGLECLOUDSTORAGEBUCKETLOCATION.fields_by_name['credentials']._options = None
  _GOOGLECLOUDSTORAGEBUCKETLOCATION.fields_by_name['credentials']._serialized_options = b'\340A\002'
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['storage_account_uri']._options = None
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['storage_account_uri']._serialized_options = b'\340A\002'
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['container_name']._options = None
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['container_name']._serialized_options = b'\340A\002'
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['client_secret_credential']._options = None
  _AZUREBLOBSTORAGECONTAINERLOCATION.fields_by_name['client_secret_credential']._serialized_options = b'\340A\002'
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['tenant_id']._options = None
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['tenant_id']._serialized_options = b'\340A\002'
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['client_id']._options = None
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['client_id']._serialized_options = b'\340A\002'
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['client_secret']._options = None
  _AZURECLIENTSECRETCREDENTIAL.fields_by_name['client_secret']._serialized_options = b'\340A\002'
  _BATCHEXPORTER.fields_by_name['ref']._options = None
  _BATCHEXPORTER.fields_by_name['ref']._serialized_options = b'\340A\002'
  _BATCHEXPORTER.fields_by_name['stream_ref']._options = None
  _BATCHEXPORTER.fields_by_name['stream_ref']._serialized_options = b'\340A\002'
  _BATCHEXPORTER.fields_by_name['key_stream_ref']._options = None
  _BATCHEXPORTER.fields_by_name['key_stream_ref']._serialized_options = b'\340A\002'
  _BATCHEXPORTER.fields_by_name['interval']._options = None
  _BATCHEXPORTER.fields_by_name['interval']._serialized_options = b'\340A\002'
  _BATCHEXPORTER.fields_by_name['sink_name']._options = None
  _BATCHEXPORTER.fields_by_name['sink_name']._serialized_options = b'\340A\002'
  _BATCHEXPORTERREF.fields_by_name['billing_id']._options = None
  _BATCHEXPORTERREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _BATCHEXPORTERREF.fields_by_name['name']._options = None
  _BATCHEXPORTERREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _BATCHEXPORTERREF.fields_by_name['project_id']._options = None
  _BATCHEXPORTERREF.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _KAFKACLUSTER.fields_by_name['ref']._options = None
  _KAFKACLUSTER.fields_by_name['ref']._serialized_options = b'\340A\002'
  _KAFKACLUSTER.fields_by_name['bootstrap_servers']._options = None
  _KAFKACLUSTER.fields_by_name['bootstrap_servers']._serialized_options = b'\340A\002'
  _KAFKACLUSTER.fields_by_name['auth_mechanism']._options = None
  _KAFKACLUSTER.fields_by_name['auth_mechanism']._serialized_options = b'\340A\002'
  _KAFKACLUSTERREF.fields_by_name['billing_id']._options = None
  _KAFKACLUSTERREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _KAFKACLUSTERREF.fields_by_name['name']._options = None
  _KAFKACLUSTERREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _KAFKACLUSTERREF.fields_by_name['project_id']._options = None
  _KAFKACLUSTERREF.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _KAFKAEXPORTER.fields_by_name['ref']._options = None
  _KAFKAEXPORTER.fields_by_name['ref']._serialized_options = b'\340A\002'
  _KAFKAEXPORTER.fields_by_name['stream_ref']._options = None
  _KAFKAEXPORTER.fields_by_name['stream_ref']._serialized_options = b'\340A\002'
  _KAFKAEXPORTER.fields_by_name['target']._options = None
  _KAFKAEXPORTER.fields_by_name['target']._serialized_options = b'\340A\002'
  _KAFKAEXPORTERREF.fields_by_name['billing_id']._options = None
  _KAFKAEXPORTERREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _KAFKAEXPORTERREF.fields_by_name['name']._options = None
  _KAFKAEXPORTERREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _KAFKAEXPORTERREF.fields_by_name['project_id']._options = None
  _KAFKAEXPORTERREF.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _KAFKAEXPORTERTARGET.fields_by_name['cluster_ref']._options = None
  _KAFKAEXPORTERTARGET.fields_by_name['cluster_ref']._serialized_options = b'\340A\002'
  _KAFKAEXPORTERTARGET.fields_by_name['topic']._options = None
  _KAFKAEXPORTERTARGET.fields_by_name['topic']._serialized_options = b'\340A\002'
  _KAFKAUSER.fields_by_name['ref']._options = None
  _KAFKAUSER.fields_by_name['ref']._serialized_options = b'\340A\002'
  _KAFKAUSER.fields_by_name['kafka_exporter_name']._options = None
  _KAFKAUSER.fields_by_name['kafka_exporter_name']._serialized_options = b'\340A\003'
  _KAFKAUSER.fields_by_name['topic']._options = None
  _KAFKAUSER.fields_by_name['topic']._serialized_options = b'\340A\003'
  _KAFKAUSER.fields_by_name['client_id']._options = None
  _KAFKAUSER.fields_by_name['client_id']._serialized_options = b'\340A\003'
  _KAFKAUSER.fields_by_name['client_secret']._options = None
  _KAFKAUSER.fields_by_name['client_secret']._serialized_options = b'\340A\003'
  _KAFKAUSER.fields_by_name['cluster_ref']._options = None
  _KAFKAUSER.fields_by_name['cluster_ref']._serialized_options = b'\340A\003'
  _KAFKAUSERREF.fields_by_name['billing_id']._options = None
  _KAFKAUSERREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _KAFKAUSERREF.fields_by_name['name']._options = None
  _KAFKAUSERREF.fields_by_name['name']._serialized_options = b'\340A\003'
  _KAFKAUSERREF.fields_by_name['project_id']._options = None
  _KAFKAUSERREF.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _CONSENTLEVELMAPPING.fields_by_name['ref']._options = None
  _CONSENTLEVELMAPPING.fields_by_name['ref']._serialized_options = b'\340A\002'
  _CONSENTLEVELMAPPING.fields_by_name['name']._options = None
  _CONSENTLEVELMAPPING.fields_by_name['name']._serialized_options = b'\340A\002'
  _CONSENTLEVELMAPPINGREF.fields_by_name['billing_id']._options = None
  _CONSENTLEVELMAPPINGREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CONSENTLEVELMAPPINGREF.fields_by_name['level']._options = None
  _CONSENTLEVELMAPPINGREF.fields_by_name['level']._serialized_options = b'\340A\002'
  _CONSENTLEVELMAPPINGREF.fields_by_name['project_id']._options = None
  _CONSENTLEVELMAPPINGREF.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _POLICY.fields_by_name['id']._options = None
  _POLICY.fields_by_name['id']._serialized_options = b'\340A\002'
  _POLICY.fields_by_name['name']._options = None
  _POLICY.fields_by_name['name']._serialized_options = b'\340A\002'
  _POLICY.fields_by_name['retention_days']._options = None
  _POLICY.fields_by_name['retention_days']._serialized_options = b'\340A\002'
  _WINDOWEDEVENTCOUNT.fields_by_name['start_time']._options = None
  _WINDOWEDEVENTCOUNT.fields_by_name['start_time']._serialized_options = b'\340A\003'
  _WINDOWEDEVENTCOUNT.fields_by_name['end_time']._options = None
  _WINDOWEDEVENTCOUNT.fields_by_name['end_time']._serialized_options = b'\340A\003'
  _WINDOWEDEVENTCOUNT.fields_by_name['event_count']._options = None
  _WINDOWEDEVENTCOUNT.fields_by_name['event_count']._serialized_options = b'\340A\003'
  _SCHEMAREF.fields_by_name['handle']._options = None
  _SCHEMAREF.fields_by_name['handle']._serialized_options = b'\340A\002'
  _SCHEMAREF.fields_by_name['name']._options = None
  _SCHEMAREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _SCHEMAREF.fields_by_name['version']._options = None
  _SCHEMAREF.fields_by_name['version']._serialized_options = b'\340A\002'
  _SCHEMAREF.fields_by_name['schema_type']._options = None
  _SCHEMAREF.fields_by_name['schema_type']._serialized_options = b'\340A\003'
  _SCHEMA.fields_by_name['ref']._options = None
  _SCHEMA.fields_by_name['ref']._serialized_options = b'\340A\002'
  _SCHEMA.fields_by_name['state']._options = None
  _SCHEMA.fields_by_name['state']._serialized_options = b'\340A\003'
  _SCHEMA.fields_by_name['fingerprint']._options = None
  _SCHEMA.fields_by_name['fingerprint']._serialized_options = b'\340A\003'
  _SCHEMAMETADATA.fields_by_name['title']._options = None
  _SCHEMAMETADATA.fields_by_name['title']._serialized_options = b'\340A\001'
  _SCHEMAMETADATA.fields_by_name['description']._options = None
  _SCHEMAMETADATA.fields_by_name['description']._serialized_options = b'\340A\001'
  _SCHEMAMETADATA.fields_by_name['create_time']._options = None
  _SCHEMAMETADATA.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _SCHEMAMETADATA.fields_by_name['icon_uri']._options = None
  _SCHEMAMETADATA.fields_by_name['icon_uri']._serialized_options = b'\340A\001'
  _SCHEMAMETADATA.fields_by_name['labels']._options = None
  _SCHEMAMETADATA.fields_by_name['labels']._serialized_options = b'\340A\001'
  _SCHEMAMETADATA.fields_by_name['domains']._options = None
  _SCHEMAMETADATA.fields_by_name['domains']._serialized_options = b'\340A\001'
  _SCHEMAMETADATA.fields_by_name['industries']._options = None
  _SCHEMAMETADATA.fields_by_name['industries']._serialized_options = b'\340A\001'
  _EVENTCONTRACTREF.fields_by_name['handle']._options = None
  _EVENTCONTRACTREF.fields_by_name['handle']._serialized_options = b'\340A\002'
  _EVENTCONTRACTREF.fields_by_name['name']._options = None
  _EVENTCONTRACTREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _EVENTCONTRACTREF.fields_by_name['version']._options = None
  _EVENTCONTRACTREF.fields_by_name['version']._serialized_options = b'\340A\002'
  _EVENTCONTRACT_PIIFIELDSENTRY._options = None
  _EVENTCONTRACT_PIIFIELDSENTRY._serialized_options = b'8\001'
  _EVENTCONTRACT.fields_by_name['ref']._options = None
  _EVENTCONTRACT.fields_by_name['ref']._serialized_options = b'\340A\002'
  _EVENTCONTRACT.fields_by_name['state']._options = None
  _EVENTCONTRACT.fields_by_name['state']._serialized_options = b'\340A\003'
  _EVENTCONTRACT.fields_by_name['schema_ref']._options = None
  _EVENTCONTRACT.fields_by_name['schema_ref']._serialized_options = b'\340A\002'
  _EVENTCONTRACT.fields_by_name['key_field']._options = None
  _EVENTCONTRACT.fields_by_name['key_field']._serialized_options = b'\340A\002'
  _EVENTCONTRACTMETADATA.fields_by_name['title']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['title']._serialized_options = b'\340A\001'
  _EVENTCONTRACTMETADATA.fields_by_name['description']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['description']._serialized_options = b'\340A\001'
  _EVENTCONTRACTMETADATA.fields_by_name['create_time']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _EVENTCONTRACTMETADATA.fields_by_name['icon_uri']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['icon_uri']._serialized_options = b'\340A\001'
  _EVENTCONTRACTMETADATA.fields_by_name['labels']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['labels']._serialized_options = b'\340A\001'
  _EVENTCONTRACTMETADATA.fields_by_name['domains']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['domains']._serialized_options = b'\340A\001'
  _EVENTCONTRACTMETADATA.fields_by_name['industries']._options = None
  _EVENTCONTRACTMETADATA.fields_by_name['industries']._serialized_options = b'\340A\001'
  _LABEL.fields_by_name['key']._options = None
  _LABEL.fields_by_name['key']._serialized_options = b'\340A\002'
  _LABEL.fields_by_name['value']._options = None
  _LABEL.fields_by_name['value']._serialized_options = b'\340A\001'
  _VALIDATION.fields_by_name['field']._options = None
  _VALIDATION.fields_by_name['field']._serialized_options = b'\340A\002'
  _VALIDATION.fields_by_name['type']._options = None
  _VALIDATION.fields_by_name['type']._serialized_options = b'\340A\002'
  _VALIDATION.fields_by_name['value']._options = None
  _VALIDATION.fields_by_name['value']._serialized_options = b'\340A\002'
  _STREAMTREE.fields_by_name['stream']._options = None
  _STREAMTREE.fields_by_name['stream']._serialized_options = b'\340A\002'
  _SINKTREE.fields_by_name['sink']._options = None
  _SINKTREE.fields_by_name['sink']._serialized_options = b'\340A\002'
  _SINKTREE._options = None
  _SINKTREE._serialized_options = b'\030\001'
  _BATCHJOB.fields_by_name['ref']._options = None
  _BATCHJOB.fields_by_name['ref']._serialized_options = b'\340A\002'
  _BATCHJOB.fields_by_name['states']._options = None
  _BATCHJOB.fields_by_name['states']._serialized_options = b'\340A\003'
  _BATCHJOB.fields_by_name['source_data']._options = None
  _BATCHJOB.fields_by_name['source_data']._serialized_options = b'\340A\002'
  _BATCHJOB.fields_by_name['consent']._options = None
  _BATCHJOB.fields_by_name['consent']._serialized_options = b'\340A\002'
  _BATCHJOB.fields_by_name['encryption']._options = None
  _BATCHJOB.fields_by_name['encryption']._serialized_options = b'\340A\002'
  _BATCHJOB.fields_by_name['event_contract_ref']._options = None
  _BATCHJOB.fields_by_name['event_contract_ref']._serialized_options = b'\340A\002'
  _BATCHJOB.fields_by_name['encrypted_data']._options = None
  _BATCHJOB.fields_by_name['encrypted_data']._serialized_options = b'\340A\002'
  _BATCHJOB.fields_by_name['encryption_keys_data']._options = None
  _BATCHJOB.fields_by_name['encryption_keys_data']._serialized_options = b'\340A\002'
  _BATCHJOB.fields_by_name['derived_data']._options = None
  _BATCHJOB.fields_by_name['derived_data']._serialized_options = b'\340A\001'
  _BATCHJOB.fields_by_name['policy_id']._options = None
  _BATCHJOB.fields_by_name['policy_id']._serialized_options = b'\340A\002'
  _EXTENDEDBATCHJOB.fields_by_name['batch_job']._options = None
  _EXTENDEDBATCHJOB.fields_by_name['batch_job']._serialized_options = b'\030\001'
  _BATCHJOBREF.fields_by_name['billing_id']._options = None
  _BATCHJOBREF.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _BATCHJOBREF.fields_by_name['id']._options = None
  _BATCHJOBREF.fields_by_name['id']._serialized_options = b'\340A\003'
  _BATCHJOBREF.fields_by_name['project_id']._options = None
  _BATCHJOBREF.fields_by_name['project_id']._serialized_options = b'\340A\003'
  _BATCHJOBSTATE.fields_by_name['state_time']._options = None
  _BATCHJOBSTATE.fields_by_name['state_time']._serialized_options = b'\340A\003'
  _BATCHJOBSTATE.fields_by_name['state']._options = None
  _BATCHJOBSTATE.fields_by_name['state']._serialized_options = b'\340A\002'
  _BATCHJOBSTATE.fields_by_name['message']._options = None
  _BATCHJOBSTATE.fields_by_name['message']._serialized_options = b'\340A\001'
  _DATACONNECTORANDTYPE.fields_by_name['data_connector_ref']._options = None
  _DATACONNECTORANDTYPE.fields_by_name['data_connector_ref']._serialized_options = b'\340A\002'
  _DATACONNECTORANDTYPE.fields_by_name['path_prefix']._options = None
  _DATACONNECTORANDTYPE.fields_by_name['path_prefix']._serialized_options = b'\340A\001'
  _DATACONNECTORANDTYPE.fields_by_name['file_name']._options = None
  _DATACONNECTORANDTYPE.fields_by_name['file_name']._serialized_options = b'\340A\001'
  _DATACONNECTORANDTYPE.fields_by_name['data_type']._options = None
  _DATACONNECTORANDTYPE.fields_by_name['data_type']._serialized_options = b'\340A\002'
  _CONSENTCONFIG.fields_by_name['default_consent_levels']._options = None
  _CONSENTCONFIG.fields_by_name['default_consent_levels']._serialized_options = b'\340A\001'
  _CONSENTCONFIG.fields_by_name['consent_level_extractor']._options = None
  _CONSENTCONFIG.fields_by_name['consent_level_extractor']._serialized_options = b'\340A\001'
  _CONSENTLEVELEXTRACTOR_FIELDPATTERNSENTRY._options = None
  _CONSENTLEVELEXTRACTOR_FIELDPATTERNSENTRY._serialized_options = b'8\001'
  _ENCRYPTIONCONFIG.fields_by_name['timestamp_config']._options = None
  _ENCRYPTIONCONFIG.fields_by_name['timestamp_config']._serialized_options = b'\340A\002'
  _ENCRYPTIONCONFIG.fields_by_name['batch_job_group_id']._options = None
  _ENCRYPTIONCONFIG.fields_by_name['batch_job_group_id']._serialized_options = b'\340A\002'
  _TIMESTAMPCONFIG.fields_by_name['field']._options = None
  _TIMESTAMPCONFIG.fields_by_name['field']._serialized_options = b'\340A\002'
  _TIMESTAMPCONFIG.fields_by_name['format']._options = None
  _TIMESTAMPCONFIG.fields_by_name['format']._serialized_options = b'\340A\002'
  _TIMESTAMPCONFIG.fields_by_name['default_time_zone']._options = None
  _TIMESTAMPCONFIG.fields_by_name['default_time_zone']._serialized_options = b'\340A\001'
  _ENCRYPTEDDATA.fields_by_name['target']._options = None
  _ENCRYPTEDDATA.fields_by_name['target']._serialized_options = b'\340A\002'
  _ENCRYPTIONKEYSDATA.fields_by_name['target']._options = None
  _ENCRYPTIONKEYSDATA.fields_by_name['target']._serialized_options = b'\340A\002'
  _DERIVEDDATA.fields_by_name['target']._options = None
  _DERIVEDDATA.fields_by_name['target']._serialized_options = b'\340A\002'
  _MICROAGGREGATIONBATCHJOB.fields_by_name['ref']._options = None
  _MICROAGGREGATIONBATCHJOB.fields_by_name['ref']._serialized_options = b'\340A\002'
  _MICROAGGREGATIONBATCHJOB.fields_by_name['states']._options = None
  _MICROAGGREGATIONBATCHJOB.fields_by_name['states']._serialized_options = b'\340A\002'
  _MICROAGGREGATIONBATCHJOB.fields_by_name['source_data']._options = None
  _MICROAGGREGATIONBATCHJOB.fields_by_name['source_data']._serialized_options = b'\340A\002'
  _MICROAGGREGATIONBATCHJOB.fields_by_name['target_data']._options = None
  _MICROAGGREGATIONBATCHJOB.fields_by_name['target_data']._serialized_options = b'\340A\002'
  _MICROAGGREGATIONBATCHJOB.fields_by_name['data_contract_ref']._options = None
  _MICROAGGREGATIONBATCHJOB.fields_by_name['data_contract_ref']._serialized_options = b'\340A\002'
  _MICROAGGREGATIONBATCHJOB.fields_by_name['aggregation_config']._options = None
  _MICROAGGREGATIONBATCHJOB.fields_by_name['aggregation_config']._serialized_options = b'\340A\002'
  _MICROAGGREGATIONCONFIG.fields_by_name['minimum_k_anonymity']._options = None
  _MICROAGGREGATIONCONFIG.fields_by_name['minimum_k_anonymity']._serialized_options = b'\340A\002'
  _DATACONTRACTREF.fields_by_name['handle']._options = None
  _DATACONTRACTREF.fields_by_name['handle']._serialized_options = b'\340A\002'
  _DATACONTRACTREF.fields_by_name['name']._options = None
  _DATACONTRACTREF.fields_by_name['name']._serialized_options = b'\340A\002'
  _DATACONTRACTREF.fields_by_name['version']._options = None
  _DATACONTRACTREF.fields_by_name['version']._serialized_options = b'\340A\002'
  _DATACONTRACT_PIIFIELDSENTRY._options = None
  _DATACONTRACT_PIIFIELDSENTRY._serialized_options = b'8\001'
  _DATACONTRACT.fields_by_name['id']._options = None
  _DATACONTRACT.fields_by_name['id']._serialized_options = b'\340A\002'
  _DATACONTRACT.fields_by_name['ref']._options = None
  _DATACONTRACT.fields_by_name['ref']._serialized_options = b'\340A\002'
  _DATACONTRACT.fields_by_name['state']._options = None
  _DATACONTRACT.fields_by_name['state']._serialized_options = b'\340A\003'
  _DATACONTRACT.fields_by_name['key_field']._options = None
  _DATACONTRACT.fields_by_name['key_field']._serialized_options = b'\340A\002'
  _DATACONTRACT.fields_by_name['pii_fields']._options = None
  _DATACONTRACT.fields_by_name['pii_fields']._serialized_options = b'\030\001'
  _FIELDMETADATA_PERSONALDATACONFIG.fields_by_name['is_pii']._options = None
  _FIELDMETADATA_PERSONALDATACONFIG.fields_by_name['is_pii']._serialized_options = b'\340A\002'
  _FIELDMETADATA_PERSONALDATACONFIG.fields_by_name['is_quasi_id']._options = None
  _FIELDMETADATA_PERSONALDATACONFIG.fields_by_name['is_quasi_id']._serialized_options = b'\340A\002'
  _FIELDMETADATA_NULLHANDLINGCONFIG.fields_by_name['type']._options = None
  _FIELDMETADATA_NULLHANDLINGCONFIG.fields_by_name['type']._serialized_options = b'\340A\002'
  _DATACONTRACTMETADATA.fields_by_name['title']._options = None
  _DATACONTRACTMETADATA.fields_by_name['title']._serialized_options = b'\340A\001'
  _DATACONTRACTMETADATA.fields_by_name['description']._options = None
  _DATACONTRACTMETADATA.fields_by_name['description']._serialized_options = b'\340A\001'
  _DATACONTRACTMETADATA.fields_by_name['create_time']._options = None
  _DATACONTRACTMETADATA.fields_by_name['create_time']._serialized_options = b'\340A\003'
  _DATACONTRACTMETADATA.fields_by_name['labels']._options = None
  _DATACONTRACTMETADATA.fields_by_name['labels']._serialized_options = b'\340A\001'
  _DATACONTRACTMETADATA.fields_by_name['domains']._options = None
  _DATACONTRACTMETADATA.fields_by_name['domains']._serialized_options = b'\340A\001'
  _DATACONTRACTMETADATA.fields_by_name['industries']._options = None
  _DATACONTRACTMETADATA.fields_by_name['industries']._serialized_options = b'\340A\001'
  _USERROLE._serialized_start=16975
  _USERROLE._serialized_end=17068
  _BATCHJOBSTATETYPE._serialized_start=17071
  _BATCHJOBSTATETYPE._serialized_end=17212
  _CONSENTLEVELTYPE._serialized_start=17214
  _CONSENTLEVELTYPE._serialized_end=17298
  _SINKTYPE._serialized_start=17300
  _SINKTYPE._serialized_end=17361
  _AUTHMECHANISM._serialized_start=17363
  _AUTHMECHANISM._serialized_end=17440
  _SCHEMATYPE._serialized_start=17442
  _SCHEMATYPE._serialized_end=17509
  _SIMPLESCHEMANODETYPE._serialized_start=17512
  _SIMPLESCHEMANODETYPE._serialized_end=17644
  _FILTERPUBLICPRIVATE._serialized_start=17646
  _FILTERPUBLICPRIVATE._serialized_end=17741
  _STATISTICALDATATYPE._serialized_start=17743
  _STATISTICALDATATYPE._serialized_end=17844
  _SUBSCRIPTIONPLAN._serialized_start=17847
  _SUBSCRIPTIONPLAN._serialized_end=17993
  _STREAM._serialized_start=205
  _STREAM._serialized_end=824
  _EXTENDEDSTREAM._serialized_start=827
  _EXTENDEDSTREAM._serialized_end=977
  _EXTENDEDSTREAMGROUP._serialized_start=980
  _EXTENDEDSTREAMGROUP._serialized_end=1169
  _MASKEDFIELDS._serialized_start=1172
  _MASKEDFIELDS._serialized_end=1511
  _MASKEDFIELDS_FIELDPATTERNSENTRY._serialized_start=1338
  _MASKEDFIELDS_FIELDPATTERNSENTRY._serialized_end=1457
  _MASKEDFIELDS_PATTERNLIST._serialized_start=1459
  _MASKEDFIELDS_PATTERNLIST._serialized_end=1511
  _LIMITS._serialized_start=1513
  _LIMITS._serialized_end=1595
  _KEYSTREAM._serialized_start=1598
  _KEYSTREAM._serialized_end=1742
  _STREAMREF._serialized_start=1744
  _STREAMREF._serialized_end=1851
  _KEYSTREAMREF._serialized_start=1853
  _KEYSTREAMREF._serialized_end=1963
  _CREDENTIALS._serialized_start=1966
  _CREDENTIALS._serialized_end=2126
  _SINK._serialized_start=2129
  _SINK._serialized_end=2352
  _SINKREF._serialized_start=2354
  _SINKREF._serialized_end=2428
  _BUCKETCONFIG._serialized_start=2431
  _BUCKETCONFIG._serialized_end=2562
  _DATACONNECTOR._serialized_start=2565
  _DATACONNECTOR._serialized_end=3126
  _DATACONNECTORREF._serialized_start=3128
  _DATACONNECTORREF._serialized_end=3232
  _DATACONNECTORDEPENDENTENTITIES._serialized_start=3235
  _DATACONNECTORDEPENDENTENTITIES._serialized_end=3542
  _AWSS3BUCKETLOCATION._serialized_start=3545
  _AWSS3BUCKETLOCATION._serialized_end=3688
  _GOOGLECLOUDSTORAGEBUCKETLOCATION._serialized_start=3690
  _GOOGLECLOUDSTORAGEBUCKETLOCATION._serialized_end=3801
  _AZUREBLOBSTORAGECONTAINERLOCATION._serialized_start=3804
  _AZUREBLOBSTORAGECONTAINERLOCATION._serialized_end=4057
  _AZURECLIENTSECRETCREDENTIAL._serialized_start=4060
  _AZURECLIENTSECRETCREDENTIAL._serialized_end=4199
  _DATATYPE._serialized_start=4201
  _DATATYPE._serialized_end=4284
  _CSVCONFIG._serialized_start=4286
  _CSVCONFIG._serialized_end=4323
  _BATCHEXPORTER._serialized_start=4326
  _BATCHEXPORTER._serialized_end=4881
  _EXTENDEDBATCHEXPORTER._serialized_start=4884
  _EXTENDEDBATCHEXPORTER._serialized_end=5021
  _BATCHEXPORTERREF._serialized_start=5023
  _BATCHEXPORTERREF._serialized_end=5137
  _KAFKACLUSTER._serialized_start=5140
  _KAFKACLUSTER._serialized_end=5390
  _KAFKACLUSTERREF._serialized_start=5392
  _KAFKACLUSTERREF._serialized_end=5505
  _KAFKAEXPORTER._serialized_start=5508
  _KAFKAEXPORTER._serialized_end=5810
  _KAFKAEXPORTERREF._serialized_start=5812
  _KAFKAEXPORTERREF._serialized_end=5926
  _KAFKAEXPORTERTARGET._serialized_start=5929
  _KAFKAEXPORTERTARGET._serialized_end=6127
  _KAFKAUSER._serialized_start=6130
  _KAFKAUSER._serialized_end=6447
  _KAFKAUSERREF._serialized_start=6449
  _KAFKAUSERREF._serialized_end=6559
  _CONSENTLEVELS._serialized_start=6561
  _CONSENTLEVELS._serialized_end=6615
  _CONSENTLEVELMAPPING._serialized_start=6617
  _CONSENTLEVELMAPPING._serialized_end=6739
  _CONSENTLEVELMAPPINGREF._serialized_start=6741
  _CONSENTLEVELMAPPINGREF._serialized_end=6863
  _POLICY._serialized_start=6866
  _POLICY._serialized_end=7187
  _POLICY_STATE._serialized_start=7102
  _POLICY_STATE._serialized_end=7187
  _WINDOWEDEVENTCOUNT._serialized_start=7190
  _WINDOWEDEVENTCOUNT._serialized_end=7372
  _SCHEMAREF._serialized_start=7375
  _SCHEMAREF._serialized_end=7550
  _SCHEMA._serialized_start=7553
  _SCHEMA._serialized_end=8273
  _SCHEMA_SIMPLESCHEMADEFINITION._serialized_start=7983
  _SCHEMA_SIMPLESCHEMADEFINITION._serialized_end=8173
  _SCHEMA_STATE._serialized_start=8175
  _SCHEMA_STATE._serialized_end=8273
  _SIMPLESCHEMANODE._serialized_start=8276
  _SIMPLESCHEMANODE._serialized_end=8557
  _SCHEMAMETADATA._serialized_start=8560
  _SCHEMAMETADATA._serialized_end=8873
  _EVENTCONTRACTREF._serialized_start=8875
  _EVENTCONTRACTREF._serialized_end=8978
  _EVENTCONTRACT._serialized_start=8981
  _EVENTCONTRACT._serialized_end=9751
  _EVENTCONTRACT_PIIFIELDSENTRY._serialized_start=9591
  _EVENTCONTRACT_PIIFIELDSENTRY._serialized_end=9651
  _EVENTCONTRACT_STATE._serialized_start=8175
  _EVENTCONTRACT_STATE._serialized_end=8273
  _EVENTCONTRACTMETADATA._serialized_start=9754
  _EVENTCONTRACTMETADATA._serialized_end=10074
  _LABEL._serialized_start=10076
  _LABEL._serialized_end=10133
  _VALIDATION._serialized_start=10135
  _VALIDATION._serialized_end=10226
  _STREAMTREE._serialized_start=10229
  _STREAMTREE._serialized_end=10611
  _SINKTREE._serialized_start=10614
  _SINKTREE._serialized_end=10773
  _BATCHJOB._serialized_start=10776
  _BATCHJOB._serialized_end=11578
  _BATCHJOBWRAPPER._serialized_start=11581
  _BATCHJOBWRAPPER._serialized_end=11816
  _EXTENDEDBATCHJOB._serialized_start=11819
  _EXTENDEDBATCHJOB._serialized_end=11973
  _BATCHJOBREF._serialized_start=11975
  _BATCHJOBREF._serialized_end=12080
  _BATCHJOBSTATE._serialized_start=12083
  _BATCHJOBSTATE._serialized_end=12268
  _DATACONNECTORANDTYPE._serialized_start=12271
  _DATACONNECTORANDTYPE._serialized_end=12536
  _CONSENTCONFIG._serialized_start=12539
  _CONSENTCONFIG._serialized_end=12726
  _CONSENTLEVELEXTRACTOR._serialized_start=12729
  _CONSENTLEVELEXTRACTOR._serialized_end=12994
  _CONSENTLEVELEXTRACTOR_FIELDPATTERNSENTRY._serialized_start=12886
  _CONSENTLEVELEXTRACTOR_FIELDPATTERNSENTRY._serialized_end=12994
  _ENCRYPTIONCONFIG._serialized_start=12997
  _ENCRYPTIONCONFIG._serialized_end=13159
  _TIMESTAMPCONFIG._serialized_start=13162
  _TIMESTAMPCONFIG._serialized_end=13307
  _ENCRYPTEDDATA._serialized_start=13309
  _ENCRYPTEDDATA._serialized_end=13404
  _ENCRYPTIONKEYSDATA._serialized_start=13406
  _ENCRYPTIONKEYSDATA._serialized_end=13506
  _DERIVEDDATA._serialized_start=13509
  _DERIVEDDATA._serialized_end=13814
  _MICROAGGREGATIONBATCHJOB._serialized_start=13817
  _MICROAGGREGATIONBATCHJOB._serialized_end=14359
  _MICROAGGREGATIONCONFIG._serialized_start=14361
  _MICROAGGREGATIONCONFIG._serialized_end=14485
  _DATACONTRACTREF._serialized_start=14487
  _DATACONTRACTREF._serialized_end=14589
  _DATACONTRACT._serialized_start=14592
  _DATACONTRACT._serialized_end=15465
  _DATACONTRACT_PIIFIELDSENTRY._serialized_start=9591
  _DATACONTRACT_PIIFIELDSENTRY._serialized_end=9651
  _DATACONTRACT_STATE._serialized_start=15367
  _DATACONTRACT_STATE._serialized_end=15465
  _FIELDMETADATA._serialized_start=15468
  _FIELDMETADATA._serialized_end=16262
  _FIELDMETADATA_PERSONALDATACONFIG._serialized_start=15883
  _FIELDMETADATA_PERSONALDATACONFIG._serialized_end=16005
  _FIELDMETADATA_NULLHANDLINGCONFIG._serialized_start=16008
  _FIELDMETADATA_NULLHANDLINGCONFIG._serialized_end=16262
  _FIELDMETADATA_NULLHANDLINGCONFIG_NULLHANDLINGTYPE._serialized_start=16172
  _FIELDMETADATA_NULLHANDLINGCONFIG_NULLHANDLINGTYPE._serialized_end=16262
  _DATACONTRACTMETADATA._serialized_start=16265
  _DATACONTRACTMETADATA._serialized_end=16552
  _PROJECT._serialized_start=16555
  _PROJECT._serialized_end=16812
  _PROJECT_STATE._serialized_start=16743
  _PROJECT_STATE._serialized_end=16812
  _USER._serialized_start=16815
  _USER._serialized_end=16973
# @@protoc_insertion_point(module_scope)
